Crate scorch

Crate scorch 

Modules

activation
The activation module defines various activation functions used in the neural network.
loss
The loss module contains loss functions used for training the neural network.

Structs

Layer
Layer represents a single layer in the neural network. It contains weights, biases, and information about the size of the layer. It also contains an activation function used to transform the output of this layer.
NeuralNetwork
NeuralNetwork represents a full feedforward neural network with multiple layers. It contains information about the input size, output size, and the layers that make up the network.